# vlbi

Some routines for dealing with the output results of the Calc/Solve Packages for a standard VLBI solution.

The description of the content and format in these output files can be found in the directory `aux_files`.

In the future, all codes will be concatenated into a Python package.

The output from Calc/Solve.

Here is the format description  http://astrogeo.org/opt64/psolve/doc/getpar_02.html

For any questions, please contact me at [niu.liu@nju.edu.cn](niu.liu@nju.edu.cn).
